# Linktap Python Library

This is a basic python library for communication with the [Linktap API](https://www.link-tap.com/#!/api-for-developers)

Original code adapted from [Simplextech udi-poly-linktap](https://github.com/simplextech/udi-poly-linktap)
